# demae

demae is a framework to build a batch program using Machine Learning.
Makes it easier to deploy your ML model into production.

This example is to fetch input from S3, transform it and push output to S3.

# License

MIT
